==> gamstransfer_3.0.3.tar.gz: gamstransfer/src/gdx/src/global/modhead.cpp <==
/*
* GAMS - General Algebraic Modeling System GDX API
 *
 * Copyright (c) 2017-2024 GAMS Software GmbH <support@gams.com>
 * Copyright (c) 2017-2024 GAMS Development Corp. <support@gams.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include "modhead.h"
#include "rtl/sysutils_p3.h"

using namespace std::literals::string_literals;

namespace global::modhead
{
#if defined(__IN_CPPMEX__)
SWStream::SWStream() : std::ofstream { fn }, start { tellp() }
{
}

SWStream::~SWStream()
{
   const bool nothingWritten { tellp() == start };
   close();
   if( nothingWritten )
      rtl::sysutils_p3::DeleteFileFromDisk( fn );
}

SWStream stubofs;
#else
std::ofstream stubofs;
#endif
}

==> gamstransfer_3.0.4.tar.gz: gamstransfer/src/gdx/src/global/modhead.cpp <==
/*
* GAMS - General Algebraic Modeling System GDX API
 *
 * Copyright (c) 2017-2024 GAMS Software GmbH <support@gams.com>
 * Copyright (c) 2017-2024 GAMS Development Corp. <support@gams.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include "modhead.h"
#include "rtl/sysutils_p3.h"

using namespace std::literals::string_literals;

namespace global::modhead
{
#if defined(__IN_CPPMEX__)
SWStream::SWStream() /*: std::ofstream { fn }, start { tellp() }*/
{
   // somehow valgrind prefers it, when we do it here
   open( fn );
   start = tellp();
}

SWStream::~SWStream()
{
   const bool nothingWritten { tellp() == start };
   close();
   if( nothingWritten )
      rtl::sysutils_p3::DeleteFileFromDisk( fn );
}

SWStream stubofs;
#else
std::ofstream stubofs;
#endif
}
